@@ -1,9 +1,10 @@
 import sys
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import Optional, Any, Union
 
 from rich.console import Console
-from rich.table import Table, Padding
+from rich.table import Table
+from rich.padding import Padding
 
 from .base import Formatter, Titles, get_options_str
 from ..command import Command, CommandOption, ParentArgs, CommandGroup
@@ -20,11 +21,12 @@ def fmt_option(option: CommandOption,
         return f'[{color}]<{option.name}>[/{color}]'
     elif show_full:
         first_arg, *other_args = option.keyword_args
+        required = f'[{color}]*[/{color}]' if option.is_required else ''
         if other_args:
             other_args = ', '.join(other_args)
-            return f'[{color}]{first_arg}[/{color}] ({other_args})'
+            return f'[{color}]{first_arg}[/{color}] ({other_args}){required}'
         else:
-            return first_arg
+            return f'[{color}]{first_arg}[/{color}]{required}'
     else:
         return '[' + sorted(option.keyword_args)[-1] + ']'
 
@@ -35,6 +37,14 @@ def fmt_cmd_options(options: list[CommandOption]) -> str:
             )
 
 
+def fmt_help(help: Union[str, None], default: Any, show_default: bool):
+    if show_default and default is not None:
+        default_str = f'[bold](default: {default})[/bold]'
+        return help + f' {default_str}' if help else default_str
+    else:
+        return help
+
+
 def get_usage(global_options: list[CommandOption],
               command: str = None,
               command_options: list[CommandOption] = None,
@@ -72,6 +82,7 @@ class RichFormatter(Formatter):
                               default_factory=lambda: Console(markup=True, highlight=False))
     cmd_color: str = 'cyan'
     option_color: str = 'cyan'
+    show_default: bool = True
 
     def _color_opt(self, opt: str):
         return f'[{self.option_color}]{opt}[/{self.option_color}]'
@@ -83,8 +94,11 @@ class RichFormatter(Formatter):
         self.print_fn = self._console.print
 
     def _print_options(self, options: list[CommandOption]):
-        self.print_rows([(self._color_opt(_name or '') + _other_args, _help)
-                         for _name, _other_args, _help in get_options_str(options)])
+        self.print_rows([(self._color_opt(_name or '') + _other_args,
+                          fmt_help(_opt.help,
+                                   _opt.default if not _opt.is_required else None,
+                                   show_default=self.show_default))
+                         for _name, _other_args, _opt in get_options_str(options)])
 
     def print_rows(self, rows: list[tuple[str, Optional[str]]]):
         table = Table(show_header=False, box=None, padding=(0, self.col_space))
@@ -190,8 +204,13 @@ class RichFormatter(Formatter):
     def print_cmd_error(self, cmd: str):
         self.print_fn(f'[red]Unknown command "[bold]{cmd}[/bold]"[/red]')
 
-    def print_param_error(self, key: str) -> None:
-        self.print_fn(f"[red]Could not find value for [bold]{key!r}[/bold][/red]")
+    def print_keyword_param_error(self, cmd: str, param: str) -> None:
+        self.print_fn(
+            f'[red]Could not find keyword parameter [bold]{param!r}[/bold] for command [bold]{cmd!r}[/bold][/red]')
 
-    def print_count_error(self, expected_count: int, count: int):
-        self.print_fn(f'[red]Expected {expected_count} positional arguments but got {count}[/red]')
+    def print_param_error(self, key: str, cmd: str) -> None:
+        self.print_fn(f"[red]Could not find value for [bold]{key!r}[/bold] in [bold]{cmd}[/bold][/red]")
+
+    def print_count_error(self, expected_count: int, count: int, cmd: str):
+        self.print_fn(
+            f'[red]Expected {expected_count} positional arguments but got {count} for command [bold]{cmd}[/bold][/red]')
