@@ -46,26 +46,26 @@ sub_cmd = cli.add_sub_parser(cmd='sub', description='A sub command')
 sub_cmd.add_option('--test', help='Test mode')
 
 
-@sub_cmd.command(cmd='bar', help='Run baz command')
-def baz_bar_main(
-        **kwargs
-):
-    pass
+@sub_cmd.command(cmd='bar', help='Run bar command')
+def sub_bar_main(**kwargs):
+    print('Running sub-bar command')
 
 
-@sub_cmd.command(cmd='toto', help='Run toto command')
-def toto_main(
+@sub_cmd.command(cmd='foo', help='Run foo command')
+def sub_foo_main(
         test: bool,
         quiet: bool,
         verbose: bool,
         foo1: int = Option(..., help='Foo argument'),
         foo2: str = Option(..., '-f', '--foo2', help='Foo2 argument'),
+        foo3: str = Option(None, '--foo3', help='Foo3 argument'),
 ):
     for name, value in [('test', test),
                         ('quiet', quiet),
                         ('verbose', verbose),
                         ('foo1', foo1),
-                        ('foo2', foo2)]:
+                        ('foo2', foo2),
+                        ('foo3', foo3)]:
         print(f'{name} = {value} ({type(value)})')
 
 
