@@ -8,12 +8,15 @@ from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Any, Optional, get_args, get_origin, Literal, TypeVar, Generic
 
-from .exceptions import ParamNotFoundError, PosParamsCountError
+from .exceptions import ParamNotFoundError, PosParamsCountError, KeywordParamNotFoundError
 
 T = TypeVar('T', str, int, float, dt.date, dt.datetime, Path, dict, Literal[None], list)
 
 
-def validate_type(data_type: Any, value: str):
+def convert_to_type(data_type: Any, value: str):
+    """
+    Converts `value` to `data_type`, if not possible raises the appropriate error
+    """
     if data_type is Any or data_type is bool:
         return value
     elif data_type is str:
@@ -41,8 +44,8 @@ def validate_type(data_type: Any, value: str):
         return value
     elif data_type is list or get_origin(data_type) is list:
         list_type = get_args(data_type)
-        return [validate_type(list_type[0] if list_type else str,
-                              x) for x in value.split(' ')]
+        return [convert_to_type(list_type[0] if list_type else str,
+                                x) for x in value.split(' ')]
     else:
         raise NotImplementedError(f'No parser implemented for data type "{data_type}"')
 
@@ -90,7 +93,7 @@ class CommandOption(Generic[T]):
         return len(self.keyword_args) == 0
 
     def validate(self, value: str) -> T:
-        return validate_type(self.data_type, value)  # type: ignore
+        return convert_to_type(self.data_type, value)  # type: ignore
 
 
 def Option(
@@ -160,7 +163,11 @@ def get_cmd_args(cmd: str, types: dict[str, Any]) -> tuple[list[str], dict[str,
             positional_args.append(_arg)
             continue
 
-        curr_type = types[keyword_arg_to_name(_arg)]
+        try:
+            curr_type = types[keyword_arg_to_name(_arg)]
+        except KeyError:
+            raise KeywordParamNotFoundError(f'Could not find parameter {_arg!r}',
+                                            _arg)
 
         if curr_type is bool:
             keyword_params[_arg] = True
